@@ -29,6 +29,7 @@ def build_pybind(cus: List[Class],
                  out_root: Optional[Union[str, Path]] = None,
                  suffix_to_compiler: Optional[Dict[str, List[str]]] = None,
                  disable_pch: bool = False,
+                 disable_anno: bool = False,
                  verbose=False):
 
     mod_name = Path(out_path).stem
@@ -77,25 +78,26 @@ def build_pybind(cus: List[Class],
         pb.get_code_units())
     cg.code_written(HEADER_ROOT, header_dict, code_fmt)
     paths += cg.code_written(SRC_ROOT, impl_dict, code_fmt)
-    pyi = pb.generate_python_interface()
-    for k, v in pyi.items():
-        k_path = k.replace(".", "/") + ".pyi"
-        k_path_parts = k.split(".")[:-1]
-        pyi_path = Path(out_path) / k_path
-        pyi_path.parent.mkdir(exist_ok=True, parents=True, mode=0o755)
-        mk_init = Path(out_path)
-        init_path = (mk_init / "__init__.pyi")
-        if not init_path.exists():
-            with init_path.open("w") as f:
-                f.write("")
-        for part in k_path_parts:
-            init_path = (mk_init / part / "__init__.pyi")
+    if not disable_anno:
+        pyi = pb.generate_python_interface()
+        for k, v in pyi.items():
+            k_path = k.replace(".", "/") + ".pyi"
+            k_path_parts = k.split(".")[:-1]
+            pyi_path = Path(out_path) / k_path
+            pyi_path.parent.mkdir(exist_ok=True, parents=True, mode=0o755)
+            mk_init = Path(out_path)
+            init_path = (mk_init / "__init__.pyi")
             if not init_path.exists():
                 with init_path.open("w") as f:
                     f.write("")
-            mk_init = mk_init / part
-        with pyi_path.open("w") as f:
-            f.write(v)
+            for part in k_path_parts:
+                init_path = (mk_init / part / "__init__.pyi")
+                if not init_path.exists():
+                    with init_path.open("w") as f:
+                        f.write("")
+                mk_init = mk_init / part
+            with pyi_path.open("w") as f:
+                f.write(v)
     return ccimport.ccimport(
         paths,
         out_path,
